@@ -103,6 +103,11 @@ class GwibberClient(gtk.Window):
     gobject.idle_add(lambda: self.resize(*self.model.settings["window_size"]))
     gobject.idle_add(lambda: self.move(*self.model.settings["window_position"]))
 
+    self.connect("configure-event", self.on_configure_event)
+
+  def on_configure_event(self, *args):
+    self.save_window_settings()
+
   def on_indicator_interest_added(self):
     # Hide the notification area icon if there is interest from the 
     # messaging menu indicator
@@ -450,6 +455,9 @@ class GwibberClient(gtk.Window):
     def perform_action(mi, act, widget, msg): act(widget, self, msg)
 
     for a in actions.MENU_ITEMS:
+      if a.action.__self__.__name__ == "private" and msg["sender"].get("is_me", 0):
+        continue
+
       if a.include(self, msg):
         image = gtk.image_new_from_icon_name(a.icon, gtk.ICON_SIZE_MENU)
         mi = gtk.ImageMenuItem()
@@ -560,7 +568,14 @@ class Client(dbus.service.Object):
     self.w.present_with_time(int(time.mktime(datetime.datetime.now().timetuple())))
     self.w.move(*self.w.model.settings["window_position"])
     stream = {'account': None, 'stream': 'replies', 'transient': False}
-    self.w.stream_view.set_state([stream])
+    if isinstance(self.w.stream_view, gwui.MultiStreamUi):
+      streams = self.w.stream_view.get_state()
+      if stream["stream"] not in str(streams):
+        streams.append(stream)
+        self.w.stream_view.set_state(streams)
+    else:
+      self.w.stream_view.set_state([stream])
+
 
   @dbus.service.method("com.GwibberClient")
   def list(self):
