@@ -755,11 +755,11 @@ class MessageStreamView(WebUi):
         messages.append(message)
 
     def dupematch(item, message):
-      if item["service"] == message["service"] and item["id"] == message["id"]:
+      if item["service"] == message["service"] and item["mid"] == message["mid"]:
         return True
 
       for item in item["dupes"]:
-        if item["service"] == message["service"] and item["id"] == message["id"]:
+        if item["service"] == message["service"] and item["mid"] == message["mid"]:
           return True
 
     # Detect duplicates
