@@ -35,7 +35,7 @@ class AccountWidget(gtk.VBox):
     self.ui.connect_signals(self)
     self.vbox_settings = self.ui.get_object("vbox_settings")
     self.pack_start(self.vbox_settings, False, False)
-    self.vbox_settings.show_all()
+    self.show_all()
     if dialog:
       dialog.get_object("vbox_create").show()
 
