@@ -82,7 +82,7 @@ def perform_operation((account, opname, args, transient)):
 
     if message_data is not None:
       for m in message_data:
-        if "mid" in m:
+        if isinstance(m, dict) and m.has_key("mid"):
           m["id"] = uuid.uuid1().hex
           m["operation"] = opname
           m["stream"] = stream
@@ -466,13 +466,13 @@ class Dispatcher(dbus.service.Object):
     with sqlite3.connect(SQLITE_DB_FILENAME) as db:
       oldid = db.execute("select max(ROWID) from messages").fetchone()[0] or 0
       
-      output = db.executemany("INSERT OR IGNORE INTO messages (%s) VALUES (%s)" % (
+      output = db.executemany("INSERT OR REPLACE INTO messages (%s) VALUES (%s)" % (
             ",".join(self.messages.columns),
             ",".join("?" * len(self.messages.columns))), items)
 
       new_items = db.execute("""
-        select * from (select * from messages where ROWID > %s and to_me = 0 ORDER BY time DESC LIMIT 10) as a union
-        select * from (select * from messages where ROWID > %s and to_me != 0 ORDER BY time DESC LIMIT 10) as b 
+        select * from (select * from messages where operation == "receive" and ROWID > %s and to_me = 0 ORDER BY time DESC LIMIT 10) as a union
+        select * from (select * from messages where operation IN ("receive", "private") and ROWID > %s and to_me != 0 ORDER BY time DESC LIMIT 10) as b 
         ORDER BY time ASC""" % (oldid, oldid)).fetchall()
 
 
