@@ -35,19 +35,18 @@ PROTOCOL_INFO = {
     "send",
     "reply",
     "receive",
-    "responses",
     "thread",
     "delete",
     "send_thread",
     "like",
     "lists",
     "list",
+    "images",
     "sincetime"
   ],
 
   "default_streams": [
     "receive",
-    "responses",
     "images",
     "lists",
   ]
@@ -90,15 +89,22 @@ class Client:
 
   def _sender(self, user):
     sender = {
+      "nick": user.get("username", str(user.get("id", user.get("uid", "")))),
       "name": user["name"],
-      "id": str(user["id"]),
-      "is_me": str(user["id"]) == self.user_id,
-      "url": user["url"],
+      "id": str(user.get("id", user.get("uid", ''))),
+      "is_me": str(user.get("id", user.get("uid", ''))) == self.user_id,
+      "url": user.get("url", user.get("profile_url", "")),
       "image": user["pic_square"],
     }
     
-    if user["url"] and not "?" in user["url"]:
-      sender["nick"] = user["url"].rsplit("/", 1)[-1]
+    if user.has_key("username"):
+      sender["nick"] = user["username"]
+    elif sender["url"] and not "?" in sender["url"]:
+      sender["nick"] = sender["url"].rsplit("/", 1)[-1]
+    elif user.has_key("id"):
+      sender["nick"] = str(user["id"])
+    else:
+      sender["nick"] = str(user.get("uid", ""))
     return sender
   
   def _message(self, data, profiles):
@@ -106,8 +112,9 @@ class Client:
     m["mid"] = str(data["post_id"])
     m["service"] = "facebook"
     m["account"] = self.account["id"]
-    m["time"] = int(mx.DateTime.DateTimeFrom(int(data['created_time'])).gmtime())
+    m["time"] = int(mx.DateTime.DateTimeFrom(int(data.get("updated_time", data["created_time"]))).gmtime())
     m["url"] = data["permalink"]
+    m["to_me"] = ("@%s" % self.account["username"]) in data["message"]
 
     if data.get("attribution", 0):
       m["source"] = util.strip_urls(data["attribution"]).replace("via ", "")
@@ -124,6 +131,10 @@ class Client:
     if data.get("actor_id", 0) in profiles:
       m["sender"] = self._sender(profiles[data["actor_id"]])
 
+    # Handle target for wall posts with a specific recipient
+    if data.get("target_id", 0) in profiles:
+      m["sender"]["name"] += u" \u25b8 %s"%(profiles[data["target_id"]]['name'])
+
     if data.get("likes", {}).get("count", None):
       m["likes"] = {
         "count": data["likes"]["count"],
@@ -158,8 +169,8 @@ class Client:
     return m
 
   def _comment(self, data, profiles):
-    user = profiles[data["fromid"]]
-    return {
+    user = profiles[int(data["fromid"])]
+    m = {
       "mid": str(data["id"]),
       "service": "facebook",
       "account": self.account["id"],
@@ -167,22 +178,19 @@ class Client:
       "text": "@%s: %s" % (self.account["username"], data["text"]),
       "content": "@%s: %s" % (self.account["username"], data["text"]),
       "html": "@%s: %s" % (self.account["username"], data["text"]),
+      "to_me": True,
       "reply": {
         "id": data["post_id"],
         "nick": self.account["username"],
         "url": POST_URL % (self.user_id, data["object_id"]),
       },
-      "sender": {
-        "nick": user["username"] or str(user["uid"]),
-        "name": user["name"],
-        "id": str(user["uid"]),
-        "url": user["profile_url"],
-        "image": user["pic_square"],
-      }
+      "sender": self._sender(user),
     }
 
+    return m
+
   def _image(self, data, profiles):
-    user = profiles[data["owner"]]
+    user = profiles[int(data["owner"])]
     return {
       "mid": str(data["object_id"]),
       "service": "facebook",
@@ -257,7 +265,11 @@ class Client:
       log.logger.debug("<STATS> facebook:friends account:%s size:%s", self.account["id"], str(friends).__len__())
 
     if not self._check_error(friends):
-      return dict((p["uid"], p) for p in friends)
+      try:
+        return dict((p["uid"], p) for p in friends)
+      except TypeError: 
+        log.logger.error("<facebook:_friends> failed to parse friend data")
+        return
     else:
       return
 
@@ -270,11 +282,17 @@ class Client:
     
     profiles = dict((p["uid"], p) for p in self._get("fql.query", query=query))
     comments = self._get("stream.getComments", post_id=id)
-    return [self._comment(comment, profiles) for comment in comments]
+    try:
+      return [self._comment(comment, profiles) for comment in comments]
+    except TypeError:
+      log.logger.error("<facebook:thread> failed to parse comments for post_id %s", id)
+      return
 
   def receive(self, since=None):
     if not since:
       since = int(mx.DateTime.DateTimeFromTicks(mx.DateTime.localtime()) - mx.DateTime.TimeDelta(hours=240.0))
+    else:
+      since = int(mx.DateTime.DateTimeFromTicks(since).localtime())
 
     data = self._get("stream.get", viewer_id=self.user_id, start_time=since, limit=80)
     
@@ -282,30 +300,14 @@ class Client:
         self.account["id"], mx.DateTime.DateTimeFromTicks(since), len(str(data)))
     
     if not self._check_error(data):
-      profiles = dict((p["id"], p) for p in data["profiles"])
-      return [self._message(post, profiles) for post in data["posts"]]
+      try:
+        profiles = dict((p["id"], p) for p in data["profiles"])
+        return [self._message(post, profiles) for post in data["posts"]]
+      except TypeError:
+        log.logger.error("<facebook:receive> failed to parse message data")
+        return
     else: return
 
-  def responses(self, since=None, limit=100):
-    if not since:
-      since = int(mx.DateTime.DateTimeFromTicks(mx.DateTime.localtime()) - mx.DateTime.TimeDelta(hours=240.0))
-
-    data = self._get("fql.query", query="""
-      SELECT id, post_id, time, fromid, text, object_id FROM comment WHERE post_id IN
-        (SELECT post_id FROM stream WHERE source_id = %s) AND
-        fromid <> %s 
-        AND time > %s
-        ORDER BY time DESC LIMIT %s
-      """ % (self.user_id, self.user_id, since, limit))
-
-    log.logger.debug("<STATS> facebook:responses account:%s since:%s size:%s",
-        self.account["id"], mx.DateTime.DateTimeFromTicks(since), len(str(data)))
-
-    if not self._check_error(data):
-      profiles = self._friends()
-      return [self._comment(comment, profiles) for comment in data]
-    else: return 
-
   def lists(self, **args):
     data = self._get("fql.query", query="""
       SELECT name, profile_url, pic_square, username, uid
@@ -314,19 +316,23 @@ class Client:
       user = data[0]
     else: return
 
-    return [self._list(l, user) for l in self._get("Stream.getFilters")]
+    return [self._list(l, user) for l in self._get("stream.getFilters")]
 
   def list(self, user, id, count=util.COUNT, since=None):
     if not since:
       since = int(mx.DateTime.DateTimeFromTicks(mx.DateTime.localtime()) - mx.DateTime.TimeDelta(hours=240.0))
+    else:
+      since = int(mx.DateTime.DateTimeFromTicks(since).localtime())
 
-    data = self._get("Stream.get", viewer_id=self.user_id, start_time=since, limit=80, filter_key=id)
+    data = self._get("stream.get", viewer_id=self.user_id, start_time=since, limit=80, filter_key=id)
     profiles = dict((p["id"], p) for p in data["profiles"])
     return [self._message(post, profiles) for post in data["posts"]]
 
   def images(self, limit=100, since=None):
     if not since:
       since = int(mx.DateTime.DateTimeFromTicks(mx.DateTime.localtime()) - mx.DateTime.TimeDelta(hours=240.0))
+    else:
+      since = int(mx.DateTime.DateTimeFromTicks(since).localtime())
 
     data = self._get("fql.query", query="""
       SELECT owner, object_id, created, src_small, src_big, link, caption
@@ -342,22 +348,38 @@ class Client:
 
     if not self._check_error(data):
       profiles = self._friends()
-      return [self._image(post, profiles) for post in data if post["owner"] in profiles]
+      try:
+        return [self._image(post, profiles) for post in data if int(post["owner"]) in profiles]
+      except TypeError:
+        log.logger.error("<facebook:images> failed to parse image data")
+        log.logger.debug("<facebook:images> %s", data)
+        return
     else: return
 
   def delete(self, message):
-    self._get("stream.remove", post_id=message["mid"])
+    result = self._get("stream.remove", post_id=message["mid"])
+    if not result:
+      log.logger.error("<facebook:delete> failed")
+      return
     return []
 
   def like(self, message):
-    self._get("stream.addLike", post_id=message["mid"])
+    result = self._get("stream.addLike", post_id=message["mid"])
+    if not result:
+      log.logger.error("<facebook:like> failed")
+      return
     return []
 
   def send(self, message):
-    self._get("users.setStatus", status=message, status_includes_verb=False)
+    result = self._get("users.setStatus", status=message, status_includes_verb=False)
+    if not result:
+      log.logger.error("<facebook:send> failed")
+      return
     return []
 
   def send_thread(self, message, target):
-    self._get("stream.addComment", post_id=target["mid"], comment=message)
+    result = self._get("stream.addComment", post_id=target["mid"], comment=message)
+    if not result:
+      log.logger.error("<facebook:send_thread> failed")
+      return
     return []
-
