@@ -38,7 +38,7 @@ class Message:
   def __init__(self, client, data):
     self.client = client
     self.account = client.account
-    self.protocol = client.account["protocol"]
+    self.service = client.account["service"]
     self.username = client.account["username"]
     if "id" in data: self.id = data["id"]
     self.sender = "%s %s" % (data["user"]["first_name"], data["user"]["last_name"])
