@@ -145,7 +145,7 @@ def isRTL(s):
 
 try:
   import pynotify
-  import gtk, gtk.gdk
+  import gtk, gtk.gdk, glib
   pynotify.init("Gwibber")
 
   def notify(title, text, icon = None, timeout = None, iconsize = 48):
@@ -160,7 +160,7 @@ try:
       pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(icon, iconsize, iconsize)
       notification.set_icon_from_pixbuf(pixbuf)
     except glib.GError as e:
-      log.logger.error("Avatar failure - %s", icon)
+      log.logger.error("Avatar failure - %s - %s", icon, e.message)
       resources.del_avatar(icon)
 
     if timeout:
