@@ -63,7 +63,7 @@ RETWEET_FORMATS = {
   "service": "{R} @{nick}: {text}",
 }
 
-VERSION_NUMBER = "2.32.0.1"
+VERSION_NUMBER = "2.32.2"
 GCONF_CLIENT_DIR = "/apps/gwibber/client/"
 
 BUG_URL = "https://bugs.launchpad.net/gwibber/+filebug"
@@ -337,3 +337,9 @@ GWIBBER_OPERATIONS = """
   }
 }
 """
+
+try:
+  import libproxy
+  proxy_factory = libproxy.ProxyFactory()
+except:
+  proxy_factory = None
