@@ -61,10 +61,7 @@ import mimetypes
 import pycurl
 import StringIO
 
-try:
-    import libproxy
-except:
-    libproxy = None
+from const import proxy_factory
 
 # try to use simplejson first, otherwise fallback to XML
 RESPONSE_FORMAT = 'JSON'
@@ -1118,9 +1115,8 @@ class Facebook(object):
         c.setopt(pycurl.HTTPHEADER, ["Accept:"])
         c.setopt(c.HTTPPOST, [(x,str(y)) for x,y in post_data.items()])
 
-        if libproxy:
-            pf = libproxy.ProxyFactory()
-            proxylist = pf.getProxies(FACEBOOK_SECURE_URL if secure else FACEBOOK_URL)
+        if proxy_factory:
+            proxylist = proxy_factory.getProxies(FACEBOOK_SECURE_URL if secure else FACEBOOK_URL)
             if proxylist:
                 proxy = proxylist[0]
                 if (proxy.find("@") != -1):
